pub(crate) fn parse_command_line_arguments<'a>(
args_without_binary: impl Into<Args<'a>>,
) -> ArgumentParsingResultExpand description
Parse Commandline arguments
Please note that e.g. env::args traditionally includes the binary name as the first
argument; However, the binary name must not be included in args_without_binary.